Module parser

Module parser 

Streaming EDIFACT parser — wraps a Tokenizer and assembles Segments.

Structs

OwnedSegmentStream
Streaming iterator over owned segments from a buffered reader.
Parser
Streaming parser over a Tokenizer.
ReaderConfig
Configuration for reader-based EDIFACT parsers.

Functions

from_bufread
Parse EDIFACT from a buffered reader.
from_bufread_stream
Parse EDIFACT from a buffered reader as a streaming iterator.
from_bufread_stream_with_config
Parse EDIFACT from a buffered reader as a streaming iterator with custom config.
from_reader
Parse EDIFACT from an arbitrary reader.
from_reader_stream
Parse EDIFACT from an arbitrary reader as a streaming iterator.
from_reader_with_config
Parse EDIFACT from an arbitrary reader as a streaming iterator with custom config.