#[non_exhaustive]pub struct GroupIdentifier<'a> {
pub group_id: &'a str,
pub app_sender: &'a str,
pub app_sender_qualifier: &'a str,
pub app_recipient: &'a str,
pub app_recipient_qualifier: &'a str,
pub group_ref: &'a str,
pub controlling_agency: &'a str,
pub version: &'a str,
pub release: &'a str,
}Expand description
Parsed identifier fields from a UNG segment.
All string slices borrow from the input bytes so they live as long as the original byte buffer. Use this for zero-allocation group routing in streaming scenarios where you need to inspect group identity without full validation.
UNG element positions (ISO 9735-1 8, 0-indexed)
[0] DE 0038 functional group identification
[1] S006 application sender id + qualifier (comp 0 / comp 1)
[2] S007 application recipient id + qualifier (comp 0 / comp 1)
[3] S004 date + time (comp 0 / comp 1)
[4] DE 0048 group reference number
[5] DE 0051 controlling agency
[6] S008 version + release (comp 0 / comp 1)Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_id: &'a strFunctional group identification (UNG DE 0038), e.g. "ORDERS".
app_sender: &'a strApplication sender identification (UNG S006 DE 0040).
app_sender_qualifier: &'a strApplication sender identification code qualifier (UNG S006 DE 0007).
app_recipient: &'a strApplication recipient identification (UNG S007 DE 0044).
app_recipient_qualifier: &'a strApplication recipient identification code qualifier (UNG S007 DE 0007).
group_ref: &'a strGroup reference number (UNG DE 0048).
controlling_agency: &'a strControlling agency (UNG DE 0051), e.g. "UN".
version: &'a strMessage version number from S008 (UNG DE 0052), e.g. "D".
release: &'a strMessage release number from S008 (UNG DE 0054), e.g. "96A".